diff libpurple/protocols/jabber/parser.c @ 15822:32c366eeeb99

sed -ie 's/gaim/purple/g'
author Sean Egan <seanegan@gmail.com>
date Mon, 19 Mar 2007 07:01:17 +0000
parents baec42670246
children 7a3a66c6530a 44b4e8bd759b
line wrap: on
line diff
--- a/libpurple/protocols/jabber/parser.c	Mon Mar 19 06:11:46 2007 +0000
+++ b/libpurple/protocols/jabber/parser.c	Mon Mar 19 07:01:17 2007 +0000
@@ -1,5 +1,5 @@
 /*
  * gaim - Jabber XML parser stuff
  *
  * Copyright (C) 2003, Nathan Walp <faceprint@faceprint.com>
  *
@@ -87,7 +87,7 @@
 			attrib[attrib_len] = '\0';
 
 			txt = attrib;
-			attrib = gaim_unescape_html(txt);
+			attrib = purple_unescape_html(txt);
 			g_free(txt);
 			xmlnode_set_attrib_with_namespace(node, (const char*) attributes[i], attrib_ns, attrib);
 			g_free(attrib);
@@ -190,7 +190,7 @@
 		js->context = xmlCreatePushParserCtxt(&jabber_parser_libxml, js, buf, len, NULL);
 		xmlParseChunk(js->context, "", 0, 0);
 	} else if (xmlParseChunk(js->context, buf, len, 0) < 0) {
-		gaim_connection_error(js->gc, _("XML Parse error"));
+		purple_connection_error(js->gc, _("XML Parse error"));
 	}
 }
@@ -1,5 +1,5 @@
 /*
- * gaim - Jabber XML parser stuff
+ * purple - Jabber XML parser stuff
  *
  * Copyright (C) 2003, Nathan Walp <faceprint@faceprint.com>